#
# spec file for package hyprpaper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __builder ninja
Name:           hyprpaper
Summary:        Wayland wallpaper utility with IPC controls
Version:        0.7.1
Release:        2.3
License:        BSD-3-Clause
URL:            https://github.com/hyprwm/hyprpaper
Source0:        https://github.com/hyprwm/hyprpaper/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  pkgconfig(gtk-layer-shell-0)
BuildRequires:  pkgconfig(hyprland-protocols)
BuildRequires:  pkgconfig(hyprlang) >= 0.2.0
BuildRequires:  pkgconfig(hyprutils) >= 0.2.0
BuildRequires:  pkgconfig(hyprwayland-scanner)
BuildRequires:  pkgconfig(libglvnd)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wayland-server) >= 1.20.0
BuildRequires:  pkgconfig(wlroots-0.18) >= 0.18.0
BuildRequires:  pkgconfig(xwaylandproto)

%description
Hyprpaper is a wallpaper utility for Hyprland.
It supports IPC controls for Hyprland and various
image formats.

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%_bindir/hyprpaper
%license LICENSE

%changelog
* Fri Dec  6 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update wlroots dependency.
* Sat Nov 16 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 0.7.1:
  * New build dep: hyprwayland-scanner
  * hyprutils: required >=0.2.0
  * ipc: use XDG_RUNTIME_DIR if available
  * fractional: reload monitor on new fs scale notifs
  * core: migrate to hyprwayland-scanner
  * Fixed getconf command in build instructions
  * Add handler "reload" to do a change of wallpaper
  * Bitmap image support
  * config: produce error instead fs::exists exceptions
  * Config: use hyprutils helper
  * Fix desc: wallpaper priority
* Thu Jun  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Simplify install to just cmake
- Remove now-unneeded make protocols
- Update to version 0.7.0:
  Fixes
  * Fixed IPC with wildcards
  * Added unload unused
  * Moved socket to match hyprland 0.40.0
  MRs
  * Disable splash message by default
  * readme: fix typos
  * ipc: Added listloaded and listactive requests
  * Fix error checking while changing wallpaper.
  * Updated link to reflect arch package movement from community to
    extra
  * Nix: add home-manager module
  * Set standard exclusively for c++
  * Add OpenSuse to the installer method list
  * hyprpaper: add splash_color configuration option
  * Added missing hyprlang-devel dependency for Fedora
  * Remove comma from monitor description
  * Fix typo in hm-module.nix
  * Move socket to XDG_RUNTIME_DIR
* Mon Apr  1 2024 ming li <mli@suse.com>
- Update to version 0.6.0:
  Notes for packagers
  * new dependency: hyprlang
  Changes
  * hyprpaper now uses hyprlang for config parsing
  * A config file is no longer required
  * Webp is now supported
  * Big-endian systems are now supported
  MRs
  * doc(README): Write about required dependencies by @arijit79 in #111
  * Fix nix build, update flake.lock by @AtaraxiaSjel in #112
  * Add webp support by @tobiichi3227 in #113
  * missing libwebp-devel for fedora by @condor0010 in #114
  * fix: check path is empty by @tobiichi3227 in #116
  * fix: build failed in big-endian system by @tobiichi3227 in #117
  * Nix: add hyprlang by @fufexan in #121
  update to version 0.5.0:
  Changes
  * fix: Read absolute path of symlinks
  * internal: fix duplicate include of math
  * feat: add splash_offset
  * readme: update opensuse deps
  * render: always draw a black background first
  * ipc: allow multiple read from IPC
  * fix: respect PREFIX in Makefile
  * surface: set fully opaque
  MRs
  * fix: Read absolute path of symlinks by @slowsage in #90
  * dupliacate include of math by @LamprosPitsillos in #95
  * add "splash_offset" by @MightyPlaza in #98
  * Update README.md by @uncomfyhalomacro in #99
  * Always draw a black background behind the wallpaper by
    @FakeMichau in #100
  * Allow multiple read from IPC + some refactor by @cylian914 in #102
  * fix: respect PREFIX in Makefile by @czadowanie in #106
* Fri Oct 13 2023 Soc Virnyl Estela <socvirnyl.estela@uncomfyhalomacro.pl>
- Update to version 0.4.0:
  * Add dependencies to readme
  * [RFC] Filetype detection without extension
  * Added support for XDG_CONFIG_HOME
  * Support for symlinks
  * Clear wallpaper from monitor before destroying ouput
  * Reset hasATarget when issuing wallpaper command
* Thu Jun  1 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Move make protocols to build section.
* Tue May 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec of hyprpaper version 0.3.0
